@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,13 +13,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from typing import (
     Any,
-    AsyncIterable,
+    AsyncIterator,
     Awaitable,
     Callable,
-    Iterable,
+    Iterator,
     Optional,
     Sequence,
     Tuple,
@@ -76,14 +74,14 @@ class ListSecretsPager:
         return getattr(self._response, name)
 
     @property
-    def pages(self) -> Iterable[service.ListSecretsResponse]:
+    def pages(self) -> Iterator[service.ListSecretsResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __iter__(self) -> Iterable[resources.Secret]:
+    def __iter__(self) -> Iterator[resources.Secret]:
         for page in self.pages:
             yield from page.secrets
 
@@ -117,7 +115,7 @@ class ListSecretsAsyncPager:
         *,
         metadata: Sequence[Tuple[str, str]] = ()
     ):
-        """Instantiate the pager.
+        """Instantiates the pager.
 
         Args:
             method (Callable): The method that was originally called, and
@@ -138,14 +136,14 @@ class ListSecretsAsyncPager:
         return getattr(self._response, name)
 
     @property
-    async def pages(self) -> AsyncIterable[service.ListSecretsResponse]:
+    async def pages(self) -> AsyncIterator[service.ListSecretsResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = await self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __aiter__(self) -> AsyncIterable[resources.Secret]:
+    def __aiter__(self) -> AsyncIterator[resources.Secret]:
         async def async_generator():
             async for page in self.pages:
                 for response in page.secrets:
@@ -204,14 +202,14 @@ class ListSecretVersionsPager:
         return getattr(self._response, name)
 
     @property
-    def pages(self) -> Iterable[service.ListSecretVersionsResponse]:
+    def pages(self) -> Iterator[service.ListSecretVersionsResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __iter__(self) -> Iterable[resources.SecretVersion]:
+    def __iter__(self) -> Iterator[resources.SecretVersion]:
         for page in self.pages:
             yield from page.versions
 
@@ -245,7 +243,7 @@ class ListSecretVersionsAsyncPager:
         *,
         metadata: Sequence[Tuple[str, str]] = ()
     ):
-        """Instantiate the pager.
+        """Instantiates the pager.
 
         Args:
             method (Callable): The method that was originally called, and
@@ -266,14 +264,14 @@ class ListSecretVersionsAsyncPager:
         return getattr(self._response, name)
 
     @property
-    async def pages(self) -> AsyncIterable[service.ListSecretVersionsResponse]:
+    async def pages(self) -> AsyncIterator[service.ListSecretVersionsResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = await self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __aiter__(self) -> AsyncIterable[resources.SecretVersion]:
+    def __aiter__(self) -> AsyncIterator[resources.SecretVersion]:
         async def async_generator():
             async for page in self.pages:
                 for response in page.versions:
